==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/nl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Reacties",
    "You commented" : "Je reageerde",
    "%1$s commented" : "%1$s heeft gereageerd",
    "{author} commented" : "{author} reageerde",
    "You commented on %1$s" : "Je reageerde op %1$s",
    "You commented on {file}" : "Je reageerde op {file}",
    "%1$s commented on %2$s" : "%1$s heeft gereageerd op %2$s",
    "{author} commented on {file}" : "{author} reageerde op {file}",
    "<strong>Comments</strong> for files" : "<strong>Reacties</strong> voor bestanden",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Je werd vermeld op \"{file}\" in een reactie door een sindsdien verwijderde gebruiker",
    "{user} mentioned you in a comment on “{file}”" : "{user} heeft je vermeld in een reactie op “{file}\"",
    "Files app plugin to add comments to files" : "Bestanden app plugin om reacties aan bestanden toe te voegen",
    "Edit comment" : "Bewerk reactie",
    "Delete comment" : "Verwijder reactie",
    "No comments yet, start the conversation!" : "Nog geen reacties, start de discussie!",
    "Retry" : "Opnieuw proberen",
    "_%n unread comment_::_%n unread comments_" : ["%n ongelezen reactie","%n ongelezen reacties"],
    "_1 new comment_::_{unread} new comments_" : ["1 nieuwe reactie","{unread} nieuwe reacties"],
    "Comment" : "Reactie",
    "Comment deleted" : "Reactie verwijderd",
    "New comment …" : "Nieuwe reactie ...",
    "Post" : "Reageer",
    "Cancel" : "Annuleren",
    "[Deleted user]" : "[Verwijderde gebruiker]",
    "More comments …" : "Meer reacties ...",
    "Save" : "Opslaan",
    "Allowed characters {count} of {max}" : "{count} van de {max} toegestane tekens",
    "Error occurred while retrieving comment with ID {id}" : "Er trad een fout op bij het ophalen van reactie met ID {id}",
    "Error occurred while updating comment with id {id}" : "Er trad een fout op bij het bijwerken van reactie met id {id}",
    "Error occurred while posting comment" : "Er trad een fout op bij plaatsen reactie"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.0-7-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/nl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Reacties",
    "You commented" : "Je reageerde",
    "%1$s commented" : "%1$s heeft gereageerd",
    "{author} commented" : "{author} reageerde",
    "You commented on %1$s" : "Je reageerde op %1$s",
    "You commented on {file}" : "Je reageerde op {file}",
    "%1$s commented on %2$s" : "%1$s heeft gereageerd op %2$s",
    "{author} commented on {file}" : "{author} reageerde op {file}",
    "<strong>Comments</strong> for files" : "<strong>Reacties</strong> voor bestanden",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Je werd vermeld op \"{file}\" in een reactie door een sindsdien verwijderde gebruiker",
    "{user} mentioned you in a comment on “{file}”" : "{user} heeft je vermeld in een reactie op “{file}\"",
    "Files app plugin to add comments to files" : "Bestanden app plugin om reacties aan bestanden toe te voegen",
    "Edit comment" : "Bewerk reactie",
    "Delete comment" : "Verwijder reactie",
    "Cancel edit" : "Annuleer bewerking",
    "Post comment" : "Plaats reactie",
    "No comments yet, start the conversation!" : "Nog geen reacties, start de discussie!",
    "No more messages" : "Geen berichten meer",
    "Retry" : "Opnieuw proberen",
    "Unable to load the comments list" : "Kan reactielijst niet laden",
    "_%n unread comment_::_%n unread comments_" : ["%n ongelezen reactie","%n ongelezen reacties"],
    "_1 new comment_::_{unread} new comments_" : ["1 nieuwe reactie","{unread} nieuwe reacties"],
    "Comment" : "Reactie",
    "An error occurred while trying to edit the comment" : "Er trad een fout op bij het bewerken van de reactie",
    "Comment deleted" : "Reactie verwijderd",
    "An error occurred while trying to delete the comment" : "Er trad een fout op bij het verwijderen van de reactie",
    "An error occurred while trying to create the comment" : "Er trad een fout op bij het creëren van de reactie",
    "New comment …" : "Nieuwe reactie ...",
    "Post" : "Reageer",
    "Cancel" : "Annuleren",
    "[Deleted user]" : "[Verwijderde gebruiker]",
    "More comments …" : "Meer reacties ...",
    "Save" : "Opslaan",
    "Allowed characters {count} of {max}" : "{count} van de {max} toegestane tekens",
    "Error occurred while retrieving comment with ID {id}" : "Er trad een fout op bij het ophalen van reactie met ID {id}",
    "Error occurred while updating comment with id {id}" : "Er trad een fout op bij het bijwerken van reactie met id {id}",
    "Error occurred while posting comment" : "Er trad een fout op bij plaatsen reactie"
},
"nplurals=2; plural=(n != 1);");
